@@ -48,6 +48,11 @@ class DepositLineDetail(QuickbooksBaseObject):
         self.CheckNum = ""
         self.TxnType = ""
 
+        self.Entity = None
+        self.ClassRef = None
+        self.AccountRef = None
+        self.PaymentMethodRef = None
+
 
 @python_2_unicode_compatible
 class DepositLine(QuickbooksBaseObject):
@@ -65,7 +70,7 @@ class DepositLine(QuickbooksBaseObject):
 
     def __init__(self):
         super(DepositLine, self).__init__()
-        self.Id = 0
+        self.Id = None
         self.LineNum = 0
         self.Description = ""
         self.Amount = 0
