@@ -66,7 +66,7 @@ class PurchaseLine(QuickbooksBaseObject):
 
     def __init__(self):
         super(PurchaseLine, self).__init__()
-        self.Id = 0
+        self.Id = None
         self.LineNum = 0
         self.Description = ""
         self.Amount = 0
